<?php

namespace Jiwei\EasyHttpSdk;

use GuzzleHttp\Psr7\Request;
use http\Exception\InvalidArgumentException;

abstract class Option
{
    const ENDPONIT_HOSTS = [
        'local' => '',
        'development' => '',
        'production' => ''
    ];
    /** @var string App Key 应用标志 */
    private $app_id;
    /** @var string App Secret 应用密钥 */
    private $app_secret;
    /** @var string SDK 的 Stage 环境 */
    private $stage = "development";
    /** @var float 超时时间 */
    private $time_out = 3.0;
    /** @var bool 调试模式 */
    private $debug = false;

    /**
     * @return \Closure
     */
    abstract public function getAuthMoudel(): \Closure;

    /**
     * @param string $app_id
     * @return Option
     */
    public function setAppId(string $app_id): self
    {
        $this->app_id = $app_id;
        return $this;
    }

    /**
     * @param string $app_secret
     * @return Option
     */
    public function setAppSecret(string $app_secret): self
    {
        $this->app_secret = $app_secret;
        return $this;
    }

    /**
     * @param string $stage
     * @return Option
     */
    public function setStage(string $stage): self
    {
        $this->stage = $stage;
        return $this;
    }

    /**
     * @param float $time_out
     * @return Option
     */
    public function setTimeout(float $time_out): self
    {
        $this->time_out = $time_out;
        return $this;
    }

    /**
     * @param bool $debug
     * @return Option
     */
    public function setDebug(bool $debug): self
    {
        $this->debug = $debug;
        return $this;
    }

    /**
     * @return string
     */
    public function getAppSecret(): string
    {
        return $this->app_secret;
    }

    /**
     * @return string
     */
    public function getBaseUrl(): string
    {

        return self::ENDPONIT_HOSTS[$this->getStage()] ?? "";
    }

    /**
     * @return string
     */
    public function getStage(): string
    {
        return $this->stage;
    }

    /**
     * @return float
     */
    public function getTimeOut(): float
    {
        return $this->time_out;
    }

    /**
     * @return string
     */
    public function getAppId(): string
    {
        return $this->app_id;
    }

    /**
     * @return bool
     */
    public function isDebug(): bool
    {
        return $this->debug;
    }
}
